from .comm import Comm
import time, sys
import RPi.GPIO as GPIO

db = Comm(host='ec2-75-101-199-232.compute-1.amazonaws.com',
         port=7599,
         password='p525f81fc5bf9a369922112084c158114e3978bc3042d9a76172a8508c7cd26ce')

GPIO.setmode(GPIO.BCM)
LED_PIN = 18
GPIO.setup(LED_PIN, GPIO.OUT)

def logit(message):
    print(message)
    sys.stdout.flush()

def blink():
    logit("high")
    GPIO.output(LED_PIN, GPIO.HIGH)
    time.sleep(2)
    logit("low")
    GPIO.output(LED_PIN, GPIO.LOW)


if __name__ == '__main__':
    try:
        while True:
            time.sleep(2)
            blink()
    except:
        logit("Bye!")
        GPIO.cleanup()


from aosong import am2315
import time, json
from .comm import Comm

db = Comm(host='ec2-75-101-199-232.compute-1.amazonaws.com',
         port=7599,
         password='p525f81fc5bf9a369922112084c158114e3978bc3042d9a76172a8508c7cd26ce')

sensor = am2315.Sensor()

def get_data():
    while True:
        tuple_data = sensor.data()
        j = {
            "humidity":tuple_data[0],
            "c":tuple_data[1],
            "f":tuple_data[2]
        }
        db.set_key('data',json.dumps(j))
        data = db.get_value_by_key('data')
        print('data=', data)
        time.sleep(2.00)


import redis

class Comm:
    def __init__(self, host, port, password):
        self._redis = redis.Redis(host=host,
                        port=port,
                        password=password)

    def set_key(self, k, v):
        self._redis.set(k, v)

    def get_value_by_key(self, k):
        return self._redis.get(k)



    # def myfunc(self):
    #     print("Hello my name is " + self.name)